:mod:`bdbcontrib.metamodels.composer`: Compound metamodel including foreign predictors
======================================================================================

.. automodule:: bdbcontrib.metamodels.composer
 :members:
